==> generator-angular-neat-0.0.3.tgz: package/app/index.js <==
'use strict';
var yeoman = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');

module.exports = yeoman.generators.Base.extend({
  initializing: function () {
    this.pkg = require('../package.json');
  },

  prompting: function () {
    var done = this.async();

    // Have Yeoman greet the user.
    this.log(yosay(
      'Welcome to the stylish ' + chalk.red('AngularNeat') + ' generator!'
    ));

    var prompts = [{
      type: 'confirm',
      name: 'someOption',
      message: 'Would you like to enable this option?',
      default: true
    }];

    this.prompt(prompts, function (props) {
      this.someOption = props.someOption;

      done();
    }.bind(this));
  },

  createFolders: function() {
    this.mkdir('app');
    this.mkdir('app/styles');
    this.mkdir('app/scripts');
    this.mkdir('app/scripts/controller');
    this.mkdir('app/images');
    this.mkdir('app/views');
    this.mkdir('test');
    this.mkdir('build');
  },

  writing: {
    app: function () {
      this.fs.copy(
        this.templatePath('_package.json'),
        this.destinationPath('package.json')
      );
      this.fs.copy(
        this.templatePath('_bower.json'),
        this.destinationPath('bower.json')
      );
      this.fs.copy(
        this.templatePath('_travis.yml'),
        this.destinationPath('travis.yml')
      );
      this.fs.copy(
        this.templatePath('_app.js'),
        this.destinationPath('app/scripts/app.js')
      );
      this.fs.copy(
        this.templatePath('_header.js'),
        this.destinationPath('app/scripts/controllers/header.js')
      );
      this.fs.copy(
        this.templatePath('_login.js'),
        this.destinationPath('app/scripts/controllers/login.js')
      );
      this.fs.copy(
        this.templatePath('_home.js'),
        this.destinationPath('app/scripts/controllers/home.js')
      );
      this.fs.copy(
        this.templatePath('_home.html'),
        this.destinationPath('app/views/home.html')
      );
      this.fs.copy(
        this.templatePath('_login.html'),
        this.destinationPath('app/views/login.html')
      );
      this.fs.copy(
        this.templatePath('build/_autoprefixer.js'),
        this.destinationPath('build/autoprefixer.js')
      );
      this.fs.copy(
        this.templatePath('build/_cdnify.js'),
        this.destinationPath('build/cdnify.js')
      );
      this.fs.copy(
        this.templatePath('build/_clean.js'),
        this.destinationPath('build/clean.js')
      );
      this.fs.copy(
        this.templatePath('build/_concurrent.js'),
        this.destinationPath('build/concurrent.js')
      );
      this.fs.copy(
        this.templatePath('build/_connect.js'),
        this.destinationPath('build/connect.js')
      );
      this.fs.copy(
        this.templatePath('build/_copy.js'),
        this.destinationPath('build/copy.js')
      );
      this.fs.copy(
        this.templatePath('build/_filerev.js'),
        this.destinationPath('build/filerev.js')
      );
      this.fs.copy(
        this.templatePath('build/_htmlmin.js'),
        this.destinationPath('build/htmlmin.js')
      );
      this.fs.copy(
        this.templatePath('build/_imagemin.js'),
        this.destinationPath('build/imagemin.js')
      );
      this.fs.copy(
        this.templatePath('build/_jshint.js'),
        this.destinationPath('build/jshint.js')
      );
      this.fs.copy(
        this.templatePath('build/_karma.js'),
        this.destinationPath('build/karma.js')
      );
      this.fs.copy(
        this.templatePath('build/_less.js'),
        this.destinationPath('build/less.js')
      );
      this.fs.copy(
        this.templatePath('build/_lesslint.js'),
        this.destinationPath('build/lesslint.js')
      );
      this.fs.copy(
        this.templatePath('build/_ngannotate.js'),
        this.destinationPath('build/ngannotate.js')
      );
      this.fs.copy(
        this.templatePath('build/_svgmin.js'),
        this.destinationPath('build/svgmin.js')
      );
      this.fs.copy(
        this.templatePath('build/_usemin.js'),
        this.destinationPath('build/usemin.js')
      );
      this.fs.copy(
        this.templatePath('build/_usemineprepare.js'),
        this.destinationPath('build/useminprepare.js')
      );
      this.fs.copy(
        this.templatePath('build/_watch.js'),
        this.destinationPath('build/watch.js')
      );
      this.fs.copy(
        this.templatePath('build/_wiredep.js'),
        this.destinationPath('build/wiredep.js')
      );
      this.fs.copy(
        this.templatePath('_Gruntfile.js'),
        this.destinationPath('Gruntfile.js')
      );
      this.fs.copy(
        this.templatePath('bowerrc'),
        this.destinationPath('.bowerrc')
      );
      this.fs.copy(
        this.templatePath('_karma.conf.js'),
        this.destinationPath('test/karma.conf.js')
      );
    },

    projectfiles: function () {
      this.fs.copy(
        this.templatePath('editorconfig'),
        this.destinationPath('.editorconfig')
      );
      this.fs.copy(
        this.templatePath('jshintrc'),
        this.destinationPath('.jshintrc')
      );
    }
  },

  install: function () {
    this.installDependencies({
      skipInstall: this.options['skip-install']
    });
  }
});

==> generator-angular-neat-0.0.4.tgz: package/app/index.js <==
'use strict';
var yeoman = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');

module.exports = yeoman.generators.Base.extend({
  initializing: function () {
    this.pkg = require('../package.json');
  },

  prompting: function () {
    var done = this.async();

    // Have Yeoman greet the user.
    this.log(yosay(
      'Welcome to the stylish ' + chalk.red('AngularNeat') + ' generator!'
    ));

    var prompts = [{
      type: 'confirm',
      name: 'someOption',
      message: 'Would you like to enable this option?',
      default: true
    }];

    this.prompt(prompts, function (props) {
      this.someOption = props.someOption;

      done();
    }.bind(this));
  },

  createFolders: function() {
    this.mkdir('app');
    this.mkdir('app/styles');
    this.mkdir('app/scripts');
    this.mkdir('app/scripts/controllers');
    this.mkdir('app/images');
    this.mkdir('app/views');
    this.mkdir('test');
    this.mkdir('build');
  },

  writing: {
    app: function () {
      this.fs.copy(
        this.templatePath('_package.json'),
        this.destinationPath('package.json')
      );
      this.fs.copy(
        this.templatePath('_bower.json'),
        this.destinationPath('bower.json')
      );
      this.fs.copy(
        this.templatePath('_travis.yml'),
        this.destinationPath('travis.yml')
      );
      this.fs.copy(
        this.templatePath('_app.js'),
        this.destinationPath('app/scripts/app.js')
      );
      this.fs.copy(
        this.templatePath('_header.js'),
        this.destinationPath('app/scripts/controllers/header.js')
      );
      this.fs.copy(
        this.templatePath('_login.js'),
        this.destinationPath('app/scripts/controllers/login.js')
      );
      this.fs.copy(
        this.templatePath('_home.js'),
        this.destinationPath('app/scripts/controllers/home.js')
      );
      this.fs.copy(
        this.templatePath('_home.html'),
        this.destinationPath('app/views/home.html')
      );
      this.fs.copy(
        this.templatePath('_login.html'),
        this.destinationPath('app/views/login.html')
      );
      this.fs.copy(
        this.templatePath('build/_autoprefixer.js'),
        this.destinationPath('build/autoprefixer.js')
      );
      this.fs.copy(
        this.templatePath('build/_cdnify.js'),
        this.destinationPath('build/cdnify.js')
      );
      this.fs.copy(
        this.templatePath('build/_clean.js'),
        this.destinationPath('build/clean.js')
      );
      this.fs.copy(
        this.templatePath('build/_concurrent.js'),
        this.destinationPath('build/concurrent.js')
      );
      this.fs.copy(
        this.templatePath('build/_connect.js'),
        this.destinationPath('build/connect.js')
      );
      this.fs.copy(
        this.templatePath('build/_copy.js'),
        this.destinationPath('build/copy.js')
      );
      this.fs.copy(
        this.templatePath('build/_filerev.js'),
        this.destinationPath('build/filerev.js')
      );
      this.fs.copy(
        this.templatePath('build/_htmlmin.js'),
        this.destinationPath('build/htmlmin.js')
      );
      this.fs.copy(
        this.templatePath('build/_imagemin.js'),
        this.destinationPath('build/imagemin.js')
      );
      this.fs.copy(
        this.templatePath('build/_jshint.js'),
        this.destinationPath('build/jshint.js')
      );
      this.fs.copy(
        this.templatePath('build/_karma.js'),
        this.destinationPath('build/karma.js')
      );
      this.fs.copy(
        this.templatePath('build/_less.js'),
        this.destinationPath('build/less.js')
      );
      this.fs.copy(
        this.templatePath('build/_lesslint.js'),
        this.destinationPath('build/lesslint.js')
      );
      this.fs.copy(
        this.templatePath('build/_ngannotate.js'),
        this.destinationPath('build/ngannotate.js')
      );
      this.fs.copy(
        this.templatePath('build/_svgmin.js'),
        this.destinationPath('build/svgmin.js')
      );
      this.fs.copy(
        this.templatePath('build/_usemin.js'),
        this.destinationPath('build/usemin.js')
      );
      this.fs.copy(
        this.templatePath('build/_useminprepare.js'),
        this.destinationPath('build/useminprepare.js')
      );
      this.fs.copy(
        this.templatePath('build/_watch.js'),
        this.destinationPath('build/watch.js')
      );
      this.fs.copy(
        this.templatePath('build/_wiredep.js'),
        this.destinationPath('build/wiredep.js')
      );
      this.fs.copy(
        this.templatePath('_Gruntfile.js'),
        this.destinationPath('Gruntfile.js')
      );
      this.fs.copy(
        this.templatePath('bowerrc'),
        this.destinationPath('.bowerrc')
      );
      this.fs.copy(
        this.templatePath('_karma.conf.js'),
        this.destinationPath('test/karma.conf.js')
      );
    },

    projectfiles: function () {
      this.fs.copy(
        this.templatePath('editorconfig'),
        this.destinationPath('.editorconfig')
      );
      this.fs.copy(
        this.templatePath('jshintrc'),
        this.destinationPath('.jshintrc')
      );
    }
  },

  install: function () {
    this.installDependencies({
      skipInstall: this.options['skip-install']
    });
  }
});
